autoDisposeOnError property
If enabled, the state will be automatically disposed on error.
- last state was an error
- user closes the FutureWidget
- if the instance closed was the only one active (listening to the AbstractFutureGen — which is a value notifier), then the error state will be deleted
- user opens again the FutureWidget
- loading screen will be shown
NB: if multiple instances of FutureWidget are active, the error state will not be disposed.
Implementation
final bool autoDisposeOnError;